<!DOCTYPE html>
{% load staticfiles %}
<link rel="stylesheet" href="{% static 'djeddit/bower_components/bootstrap/dist/css/bootstrap.css' %}">
<link rel="stylesheet" href="{% static 'djeddit/bower_components/font-awesome/css/font-awesome.min.css' %}">
<link rel="stylesheet" href="{% static 'djeddit/bower_components/bootstrap-select/dist/css/bootstrap-select.min.css' %}">
<!-- Bootstrap theme -->
<link rel="stylesheet" href="{% static 'djeddit/css/theme.css' %}">
<link rel="stylesheet" href="{% static 'djeddit/css/callout.css' %}">
