<!DOCTYPE html>
{% load djeddit_tags %}
<li class="list-group-item">
    <div class="row vertical-align">
        <div class="col-sm-1 hidden-xs col-icon hover-point" onclick="window.location='{% url 'topicPage' topic.urlTitle %}'">
            <i class="fa fa-comments-o fa-2x"></i>
        </div>
        <div class="col-sm-10 col-xs-11 list-group-item-main-col">
            <a href="{% url 'topicPage' topic.urlTitle %}">
                <h4 class="inline">{{ topic.title }}</h4>
            </a>
            <br>
            <div class="text-muted inline full-line">
                {% firstLine topic.description 90 %}
            </div>
        </div>
        <div class="col-xs-1">
            <div class="count-box" onclick="window.location='{% url 'topicPage' topic.urlTitle %}'">
                <div class="count-box-score text-muted">{{ topic.getThreadCount }}</div>
                <div class="count-box-context text-muted">Threads</div>
            </div>
        </div>
    </div>
</li>