.bs-callout {
  padding: 10px 20px;
  margin: 10px 0;
  border: 1px solid #ddd;
  border-radius: 3px;
  background: #fff; }
  .bs-callout textarea {
    resize: vertical;
    height: 140px; }

.bs-callout h4 {
  margin-top: 0;
  margin-bottom: 5px; }

.bs-callout p:last-child {
  margin-bottom: 0; }

.bs-callout code {
  border-radius: 3px; }

.bs-callout + .bs-callout {
  margin-top: -5px; }

.bs-callout-default {
  border-left-color: #777; }

.bs-callout-default h4 {
  color: #777; }

.bs-callout-primary {
  border-left-color: #428bca; }

.bs-callout-primary h4 {
  color: #428bca; }

.bs-callout-success {
  border-left-color: #5cb85c; }

.bs-callout-success h4 {
  color: #5cb85c; }

.bs-callout-danger {
  border-left-color: #d9534f; }

.bs-callout-danger h4 {
  color: #d9534f; }

.bs-callout-warning {
  border-left-color: #f0ad4e; }

.bs-callout-warning h4 {
  color: #f0ad4e; }

.bs-callout-info {
  border-left-color: #5bc0de; }

.bs-callout-info h4 {
  color: #5bc0de; }

.bs-callout-heading {
  margin-left: 15px; }
  .bs-callout-heading h3, .bs-callout-heading h4, .bs-callout-heading h5, .bs-callout-heading h6 {
    display: inline; }

.minicol {
  float: left;
  margin: 10px 0;
  text-align: center; }
  .minicol .glyphicon {
    display: block; }
  .minicol .post-score {
    margin-bottom: 0;
    margin-top: 3px;
    line-height: 1.3; }

.glyphicon-chevron-up-op {
  margin-bottom: 7px; }

.postcol {
  display: inline-block;
  margin-left: 10px;
  margin-top: 5px; }

.callout-title {
  line-height: 1;
  margin-top: 5px !important;
  padding-left: 15px;
  padding-right: 15px; }

/*# sourceMappingURL=callout.css.map */
