<!DOCTYPE html>
{% load staticfiles %}
<script type="text/javascript" src="{% static 'djeddit/bower_components/jquery/dist/jquery.min.js' %}"></script>
<script type="text/javascript" src="{% static 'djeddit/bower_components/bootstrap/dist/js/bootstrap.min.js' %}"></script>
<script type="text/javascript" src="{% static 'djeddit/bower_components/bootstrap-select/dist/js/bootstrap-select.min.js' %}"></script>
<script type="text/javascript" src="{% static 'djeddit/js/ie10-viewport-bug-workaround.js' %}"></script>
<script type="text/javascript" src="{% static 'djeddit/js/csrf.js' %}"></script>
<script type="text/javascript" src="{% static 'djeddit/js/url-join.js' %}"></script>
